@@ -96,17 +96,15 @@ static void parse_preamble(struct parser *p) {
 					endptr);
 			exit(EXIT_FAILURE);
 		}
-		if (epoch > ULONG_MAX) {
-			fprintf(stderr, "$SOURCE_DATE_EPOCH: value must be smaller than or "
-					"equal to %lu but was found to be: %llu \n",
-					ULONG_MAX, epoch);
-			exit(EXIT_FAILURE);
-		}
 		date_time = epoch;
 	} else {
 		date_time = time(NULL);
 	}
 	struct tm *date_tm = gmtime(&date_time);
+	if (date_tm == NULL) {
+		fprintf(stderr, "gmtime: failed");
+		exit(EXIT_FAILURE);
+	}
 	strftime(date, sizeof(date), "%F", date_tm);
 	while ((ch = parser_getch(p)) != UTF8_INVALID) {
 		if ((ch < 0x80 && isalnum((unsigned char)ch))
@@ -200,8 +198,18 @@ static bool parse_linebreak(struct parser *p) {
 
 static void parse_text(struct parser *p) {
 	uint32_t ch, next, last = ' ';
+	bool chomp_next_indent = false;
 	int i = 0;
 	while ((ch = parser_getch(p)) != UTF8_INVALID) {
+		// skip indentation if last was a linebreak
+		// and we need to chomp indentation
+		if (chomp_next_indent) {
+			if (ch == '\t' || ch == ' ') {
+				continue;
+			}
+			chomp_next_indent = false;
+		}
+
 		switch (ch) {
 		case '\\':
 			ch = parser_getch(p);
@@ -235,6 +243,7 @@ static void parse_text(struct parser *p) {
 		case '+':
 			if (parse_linebreak(p)) {
 				last = '\n';
+				chomp_next_indent = true;
 			}
 			break;
 		case '\n':
@@ -261,6 +270,14 @@ static void parse_text(struct parser *p) {
 			// Suppress sentence spacing
 			fprintf(p->output, "\\&");
 			break;
+		case '~':
+			// Escape ~ to not render it with U+02DC
+			fprintf(p->output, "\\(ti");
+			break;
+		case '^':
+			// Escape ^ to not render it with U+02C6
+			fprintf(p->output, "\\(ha");
+			break;
 		default:
 			last = ch;
 			utf8_fputch(p->output, ch);
@@ -729,6 +746,11 @@ static void parse_document(struct parser *p) {
 			break;
 		}
 	} while (ch != UTF8_INVALID);
+	// Close out any residual indent at EOF
+	while (indent > 0) {
+		roff_macro(p, "RE", NULL);
+		indent--;
+	}
 }
 
 static void output_scdoc_preamble(struct parser *p) {
